@@ -110,10 +110,7 @@ class OptionParser(argparse.ArgumentParser):
         """ Parse setopts arguments and put them into main_<setopts>
             and repo_<setopts>."""
         def __call__(self, parser, namespace, values, opt_str):
-            vals = values.split('=')
-            if len(vals) > 2:
-                logger.warning(_("Setopt argument has multiple values: %s"), values)
-                return
+            vals = values.split('=', maxsplit=1)
             if len(vals) < 2:
                 logger.warning(_("Setopt argument has no value: %s"), values)
                 return
@@ -174,7 +171,7 @@ class OptionParser(argparse.ArgumentParser):
         general_grp = self.add_argument_group(_('General {prog} options'.format(
             prog=dnf.util.MAIN_PROG_UPPER)))
         general_grp.add_argument("-c", "--config", dest="config_file_path",
-                                 default=None, metavar='CONFIG_FILE',
+                                 default=None, metavar='[config file]',
                                  help=_("config file location"))
         general_grp.add_argument("-q", "--quiet", dest="quiet",
                                  action="store_true", default=None,
@@ -185,7 +182,7 @@ class OptionParser(argparse.ArgumentParser):
                                  help=_("show {prog} version and exit").format(
                                      prog=dnf.util.MAIN_PROG_UPPER))
         general_grp.add_argument("--installroot", help=_("set install root"),
-                                 metavar='PATH')
+                                 metavar='[path]')
         general_grp.add_argument("--nodocs", action="store_const", const=['nodocs'], dest='tsflags',
                                  help=_("do not install documentations"))
         general_grp.add_argument("--noplugins", action="store_false",
@@ -194,20 +191,14 @@ class OptionParser(argparse.ArgumentParser):
         general_grp.add_argument("--enableplugin", dest="enableplugin",
                                  default=[], action=self._SplitCallback,
                                  help=_("enable plugins by name"),
-                                 metavar='PLUGIN')
+                                 metavar='[plugin]')
         general_grp.add_argument("--disableplugin", dest="disableplugin",
                                  default=[], action=self._SplitCallback,
                                  help=_("disable plugins by name"),
-                                 metavar='PLUGIN')
+                                 metavar='[plugin]')
         general_grp.add_argument("--releasever", default=None,
                                  help=_("override the value of $releasever"
                                         " in config and repo files"))
-        general_grp.add_argument("--releasever-major", default=None,
-                                 help=_("override the value of $releasever_major"
-                                        " in config and repo files"))
-        general_grp.add_argument("--releasever-minor", default=None,
-                                 help=_("override the value of $releasever_minor"
-                                        " in config and repo files"))
         general_grp.add_argument("--setopt", dest="setopts", default=[],
                                  action=self._SetoptsCallback,
                                  help=_("set arbitrary config and repo options"))
@@ -232,10 +223,10 @@ class OptionParser(argparse.ArgumentParser):
                                  help=_("run entirely from system cache, "
                                         "don't update cache"))
         general_grp.add_argument("-R", "--randomwait", dest="sleeptime", type=int,
-                                 default=None, metavar='MINUTES',
+                                 default=None, metavar='[minutes]',
                                  help=_("maximum command wait time"))
         general_grp.add_argument("-d", "--debuglevel", dest="debuglevel",
-                                 metavar='DEBUG_LEVEL', default=None,
+                                 metavar='[debug level]', default=None,
                                  help=_("debugging output level"), type=int)
         general_grp.add_argument("--debugsolver",
                                  action="store_true", default=None,
@@ -255,7 +246,7 @@ class OptionParser(argparse.ArgumentParser):
                                         "repoquery").format(prog=dnf.util.MAIN_PROG))
         general_grp.add_argument("--rpmverbosity", default=None,
                                  help=_("debugging output level for rpm"),
-                                 metavar='DEBUG_LEVEL_NAME')
+                                 metavar='[debug level name]')
         general_grp.add_argument("-y", "--assumeyes", action="store_true",
                                  default=None, help=_("automatically answer yes"
                                                       " for all questions"))
@@ -263,20 +254,20 @@ class OptionParser(argparse.ArgumentParser):
                                  default=None, help=_("automatically answer no"
                                                       " for all questions"))
         general_grp.add_argument("--enablerepo", action=self._RepoCallback,
-                                 dest='repos_ed', default=[], metavar='REPO',
+                                 dest='repos_ed', default=[], metavar='[repo]',
                                  help=_("Temporarily enable repositories for the purpose "
                                         "of the current dnf command. Accepts an id, a "
                                         "comma-separated list of ids, or a glob of ids. "
                                         "This option can be specified multiple times."))
         repo_group = general_grp.add_mutually_exclusive_group()
         repo_group.add_argument("--disablerepo", action=self._RepoCallback,
-                                dest='repos_ed', default=[], metavar='REPO',
+                                dest='repos_ed', default=[], metavar='[repo]',
                                 help=_("Temporarily disable active repositories for the "
                                        "purpose of the current dnf command. Accepts an id, "
                                        "a comma-separated list of ids, or a glob of ids. "
                                        "This option can be specified multiple times, but "
                                        "is mutually exclusive with `--repo`."))
-        repo_group.add_argument('--repo', '--repoid', metavar='REPO', dest='repo',
+        repo_group.add_argument('--repo', '--repoid', metavar='[repo]', dest='repo',
                                 action=self._SplitCallback, default=[],
                                 help=_('enable just specific repositories by an id or a glob, '
                                        'can be specified multiple times'))
@@ -292,15 +283,15 @@ class OptionParser(argparse.ArgumentParser):
         general_grp.add_argument("-x", "--exclude", "--excludepkgs", default=[],
                                  dest='excludepkgs', action=self._SplitCallback,
                                  help=_("exclude packages by name or glob"),
-                                 metavar='PACKAGE')
+                                 metavar='[package]')
         general_grp.add_argument("--disableexcludes", "--disableexcludepkgs",
                                  default=[], dest="disable_excludes",
                                  action=self._SplitCallback,
                                  help=_("disable excludepkgs"),
-                                 metavar='{all, main, REPOID}')
+                                 metavar='[repo]')
         general_grp.add_argument("--repofrompath", default={},
                                  action=self._SplitExtendDictCallback,
-                                 metavar='REPO,PATH',
+                                 metavar='[repo,path]',
                                  help=_("label and path to an additional repository to use (same "
                                         "path as in a baseurl), can be specified multiple times."))
         general_grp.add_argument("--noautoremove", action="store_false",
